@@ -16,7 +16,7 @@ use Video::Generator;
 Readonly::Scalar our $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Constructor.
 sub new {
@@ -77,7 +77,9 @@ sub run {
 		if ($self->{'_opts'}->{'i'} ne $EMPTY_STR) {
 			$image_generator = Image::Select->new(
 				'debug' => ($self->{'_opts'}->{'v'} ? 1 : 0),
+				'height' => $self->{'_height'},
 				'path_to_images' => $self->{'_opts'}->{'i'},
+				'width' => $self->{'_width'},
 			);
 		}
 
@@ -191,6 +193,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
